@@ -266,6 +266,34 @@ gncOwnerApplyPayment (const GncOwner *owner, Transaction *txn, GList *lots,
                       gnc_numeric amount, gnc_numeric exch, Timespec date,
                       const char *memo, const char *num, gboolean auto_pay);
 
+/** Helper function to find a split in lot that best offsets target_value
+ *  Obviously it should be of opposite sign.
+ * If there are more splits of opposite sign the following
+ * criteria are used in order of preference:
+ * 1. exact match in abs value is preferred over larger abs value
+ * 2. larger abs value is preferred over smaller abs value
+ * 3. if previous and new candidate are in the same value category,
+ *    prefer real payment splits over lot link splits
+ * 4. if previous and new candiate are of same split type
+ *    prefer biggest abs value.
+ */
+Split *gncOwnerFindOffsettingSplit (GNCLot *pay_lot, gnc_numeric target_value);
+
+/** Helper function to reduce the value of a split to target_value. To make
+ *  sure the split's parent transaction remains balanced a second split
+ *  will be created with the remainder. Similarly if the split was part of a
+ *  (business) lot, the remainder split will be added to the same lot to
+ *  keep the lot's balance unchanged.
+ */
+gboolean gncOwnerReduceSplitTo (Split *split, gnc_numeric target_value);
+
+/** To help a user understand what a lot link transaction does,
+ *  we set the memo to name all documents involved in the link.
+ *  The function below calculates this memo and sets it for
+ *  all splits in the lot link transaction.
+ */
+void gncOwnerSetLotLinkMemo (Transaction *ll_txn);
+
 /** Returns a GList of account-types based on the owner type */
 GList * gncOwnerGetAccountTypesList (const GncOwner *owner);
 
