@@ -215,7 +215,7 @@ teardown (Fixture *fixture, gconstpointer pData)
     test_destroy (fixture->curr);
     test_destroy (fixture->comm);
     g_free (mbe);
-    test_destroy (book);
+    qof_book_destroy(book);
     g_slist_free_full (fixture->hdlrs, test_free_log_handler);
     test_clear_error_list();
 }
@@ -387,7 +387,7 @@ test_gnc_transaction_dispose ()
     test_destroy (curr);
 
     test_destroy (txn);
-    test_destroy (book);
+    qof_book_destroy (book);
 }
 /* gnc_transaction_finalize
 static void
@@ -473,7 +473,7 @@ test_gnc_transaction_set_get_property (Fixture *fixture, gconstpointer pData)
     xaccTransRollbackEdit (txn);
     test_destroy (txn);
     test_destroy (curr);
-    test_destroy (book);
+    qof_book_destroy (book);
     g_free (t_entered);
 }
 /* gnc_transaction_class_init
@@ -511,7 +511,7 @@ test_xaccMallocTransaction (Fixture *fixture, gconstpointer pData)
     test_signal_assert_hits (sig1, 1);
 
     test_destroy (txn);
-    test_destroy (book);
+    qof_book_destroy (book);
     test_signal_free (sig1);
 }
 /* xaccTransSortSplits
@@ -1420,7 +1420,7 @@ test_xaccTransDestroy ()
 
     test_destroy (txn);
     test_destroy (dupe);
-    test_destroy (book);
+    qof_book_destroy (book);
 }
 /* destroy_gains
 static void
@@ -1674,7 +1674,7 @@ test_xaccTransCommitEdit (void)
     test_destroy (acc2);
     test_destroy (curr);
     test_destroy (comm);
-    test_destroy (book);
+    qof_book_destroy (book);
 }
 /* xaccTransRollbackEdit
 void
@@ -2075,8 +2075,8 @@ test_suite_transaction (void)
     GNC_TEST_ADD (suitename, "xaccTransOrder_num_action", Fixture, NULL, setup, test_xaccTransOrder_num_action, teardown);
     GNC_TEST_ADD (suitename, "xaccTransVoid", Fixture, NULL, setup, test_xaccTransVoid, teardown);
     GNC_TEST_ADD (suitename, "xaccTransReverse", Fixture, NULL, setup, test_xaccTransReverse, teardown);
-    GNC_TEST_ADD (suitename, "xaccTransScrubGainsDate", GainsFixture, NULL, setup_with_gains, test_xaccTransScrubGainsDate_no_dirty, teardown_with_gains);
-    GNC_TEST_ADD (suitename, "xaccTransScrubGainsDate", GainsFixture, NULL, setup_with_gains, test_xaccTransScrubGainsDate_base_dirty, teardown_with_gains);
-    GNC_TEST_ADD (suitename, "xaccTransScrubGainsDate", GainsFixture, NULL, setup_with_gains, test_xaccTransScrubGainsDate_gains_dirty, teardown_with_gains);
+    GNC_TEST_ADD (suitename, "xaccTransScrubGainsDate_no_dirty", GainsFixture, NULL, setup_with_gains, test_xaccTransScrubGainsDate_no_dirty, teardown_with_gains);
+    GNC_TEST_ADD (suitename, "xaccTransScrubGainsDate_base_dirty", GainsFixture, NULL, setup_with_gains, test_xaccTransScrubGainsDate_base_dirty, teardown_with_gains);
+    GNC_TEST_ADD (suitename, "xaccTransScrubGainsDate_gains_dirty", GainsFixture, NULL, setup_with_gains, test_xaccTransScrubGainsDate_gains_dirty, teardown_with_gains);
 
 }
