@@ -37,7 +37,6 @@
 
 #include "gnc-component-manager.h"
 
-#include "assistant-utils.h"
 #include "assistant-csv-account-import.h"
 #include "csv-account-import.h"
 
@@ -519,7 +518,7 @@ csv_import_assistant_prepare (GtkAssistant *assistant, GtkWidget *page,
  * Assistant call back functions
  *******************************************************/
 static void
-csv_import_assistant_destroy_cb (GtkObject *object, gpointer user_data)
+csv_import_assistant_destroy_cb (GtkWidget *object, gpointer user_data)
 {
     CsvImportInfo *info = user_data;
     gnc_unregister_gui_component_by_data (ASSISTANT_CSV_IMPORT_CM_CLASS, info);
@@ -583,9 +582,6 @@ csv_import_assistant_create (CsvImportInfo *info)
     window = GTK_WIDGET(gtk_builder_get_object (builder, "CSV Account Import Assistant"));
     info->window = window;
 
-    /* Set the assistant colors */
-    gnc_assistant_set_colors (GTK_ASSISTANT (info->window));
-
     /* Load default settings */
     load_settings (info);
 
