@@ -29,6 +29,13 @@
 (define-module (gnucash report view-column))
 (use-modules (gnucash main)) ;; FIXME: delete after we finish modularizing.
 (use-modules (gnucash gnc-module))
+(use-modules (gnucash gettext))
+(cond-expand
+  (guile-2
+    (eval-when
+      (compile load eval expand)
+      (load-extension "libgncmod-report-system" "scm_init_sw_report_system_module")))
+  (else ))
 (use-modules (sw_report_system))
 
 (use-modules (gnucash printf))
